==> thrio-0.2.0.tar.gz: ios/Classes/Navigator/NavigatorFlutterEngineFactory.h <==
// The MIT License (MIT)
//
// Copyright (c) 2019 Hellobike Group
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import <Foundation/Foundation.h>
#import <Flutter/Flutter.h>
#import "NavigatorFlutterViewController.h"
#import "ThrioTypes.h"
#import "NavigatorRouteSendChannel.h"
#import "NavigatorPageObserverChannel.h"

NS_ASSUME_NONNULL_BEGIN

@interface NavigatorFlutterEngineFactory : NSObject

+ (instancetype)shared;

- (void)startupWithEntrypoint:(NSString *)entrypoint readyBlock:(ThrioIdCallback _Nullable)block;

- (FlutterEngine *)getEngineByEntrypoint:(NSString *)entrypoint;

- (NavigatorRouteSendChannel *)getSendChannelByEntrypoint:(NSString *)entrypoint;

- (NavigatorPageObserverChannel *)getPageObserverChannelByEntrypoint:(NSString *)entrypoint;

- (void)pushViewController:(NavigatorFlutterViewController *)viewController;

- (void)popViewController:(NavigatorFlutterViewController *)viewController;

- (void)registerFlutterUrls:(NSArray *)urls;

- (void)unregisterFlutterUrls:(NSArray *)urls;

@end

NS_ASSUME_NONNULL_END

==> thrio-1.7.5.tar.gz: ios/Classes/Navigator/NavigatorFlutterEngineFactory.h <==
// The MIT License (MIT)
//
// Copyright (c) 2019 Hellobike Group
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
// IN THE SOFTWARE.

#import <Foundation/Foundation.h>
#import <Flutter/Flutter.h>
#import "NavigatorFlutterViewController.h"
#import "ThrioTypes.h"
#import "NavigatorRouteSendChannel.h"
#import "NavigatorPageObserverProtocol.h"
#import "NavigatorRouteObserverProtocol.h"

NS_ASSUME_NONNULL_BEGIN

@interface NavigatorFlutterEngineFactory : NSObject<
        NavigatorPageObserverProtocol,
        NavigatorRouteObserverProtocol>

@property (nonatomic) BOOL multiEngineEnabled;

+ (instancetype)shared;

- (void)startupWithEntrypoint:(NSString *)entrypoint readyBlock:(ThrioIdCallback _Nullable)block;

- (FlutterEngine *)getEngineByEntrypoint:(NSString *)entrypoint;

- (NavigatorRouteSendChannel *)getSendChannelByEntrypoint:(NSString *)entrypoint;

- (void)pushViewController:(NavigatorFlutterViewController *)viewController;

- (void)popViewController:(NavigatorFlutterViewController *)viewController;

- (void)registerFlutterUrls:(NSArray *)urls;

- (void)unregisterFlutterUrls:(NSArray *)urls;

@end

NS_ASSUME_NONNULL_END
